==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/equipmentmeterreading_001/EquipmentMeterReading.java <==

package net.datastream.schemas.mp_entities.equipmentmeterreading_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.READINGTYPEID_Type;
import net.datastream.schemas.mp_fields.STANDARDENTITYID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import net.datastream.schemas.mp_fields.WOID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMETERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}READINGTYPEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}READINGDATE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NEWVALUE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CHILDREADING" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmeterid",
    "equipmentid",
    "type",
    "uomid",
    "readingtypeid",
    "readingdate",
    "newvalue",
    "workorderid",
    "relatedworkorderid",
    "childreading",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "EquipmentMeterReading")
public class EquipmentMeterReading {

    @XmlElement(name = "EQUIPMETERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STANDARDENTITYID_Type equipmeterid;
    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "READINGTYPEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected READINGTYPEID_Type readingtypeid;
    @XmlElement(name = "READINGDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME readingdate;
    @XmlElement(name = "NEWVALUE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY newvalue;
    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;
    @XmlElement(name = "RELATEDWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "CHILDREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected String childreading;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the equipmeterid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getEQUIPMETERID() {
        return equipmeterid;
    }

    /**
     * Sets the value of the equipmeterid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setEQUIPMETERID(STANDARDENTITYID_Type value) {
        this.equipmeterid = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the readingtypeid property.
     * 
     * @return
     *     possible object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public READINGTYPEID_Type getREADINGTYPEID() {
        return readingtypeid;
    }

    /**
     * Sets the value of the readingtypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public void setREADINGTYPEID(READINGTYPEID_Type value) {
        this.readingtypeid = value;
    }

    /**
     * Gets the value of the readingdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREADINGDATE() {
        return readingdate;
    }

    /**
     * Sets the value of the readingdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREADINGDATE(DATETIME value) {
        this.readingdate = value;
    }

    /**
     * Gets the value of the newvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getNEWVALUE() {
        return newvalue;
    }

    /**
     * Sets the value of the newvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setNEWVALUE(QUANTITY value) {
        this.newvalue = value;
    }

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the childreading property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHILDREADING() {
        return childreading;
    }

    /**
     * Sets the value of the childreading property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHILDREADING(String value) {
        this.childreading = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/equipmentmeterreading_001/EquipmentMeterReading.java <==

package net.datastream.schemas.mp_entities.equipmentmeterreading_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.READINGTYPEID_Type;
import net.datastream.schemas.mp_fields.STANDARDENTITYID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import net.datastream.schemas.mp_fields.WOID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMETERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READINGTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READINGDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWVALUE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHILDREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmeterid",
    "equipmentid",
    "type",
    "uomid",
    "readingtypeid",
    "readingdate",
    "newvalue",
    "workorderid",
    "relatedworkorderid",
    "childreading",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "EquipmentMeterReading")
public class EquipmentMeterReading {

    @XmlElement(name = "EQUIPMETERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STANDARDENTITYID_Type equipmeterid;
    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "READINGTYPEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected READINGTYPEID_Type readingtypeid;
    @XmlElement(name = "READINGDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME readingdate;
    @XmlElement(name = "NEWVALUE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY newvalue;
    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;
    @XmlElement(name = "RELATEDWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "CHILDREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected String childreading;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the equipmeterid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getEQUIPMETERID() {
        return equipmeterid;
    }

    /**
     * Sets the value of the equipmeterid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setEQUIPMETERID(STANDARDENTITYID_Type value) {
        this.equipmeterid = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the readingtypeid property.
     * 
     * @return
     *     possible object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public READINGTYPEID_Type getREADINGTYPEID() {
        return readingtypeid;
    }

    /**
     * Sets the value of the readingtypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link READINGTYPEID_Type }
     *     
     */
    public void setREADINGTYPEID(READINGTYPEID_Type value) {
        this.readingtypeid = value;
    }

    /**
     * Gets the value of the readingdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREADINGDATE() {
        return readingdate;
    }

    /**
     * Sets the value of the readingdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREADINGDATE(DATETIME value) {
        this.readingdate = value;
    }

    /**
     * Gets the value of the newvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getNEWVALUE() {
        return newvalue;
    }

    /**
     * Sets the value of the newvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setNEWVALUE(QUANTITY value) {
        this.newvalue = value;
    }

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the childreading property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHILDREADING() {
        return childreading;
    }

    /**
     * Sets the value of the childreading property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHILDREADING(String value) {
        this.childreading = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
